Trait cobyla::ObjFn

source ·
pub trait ObjFn<U>: Fn(&[f64], &mut U) -> f64 { }
A trait for an objective function to be minimized

An objective function takes the form of a closure f(x: &[f64], user_data: &mut U) -> f64

  • x - n-dimensional array
  • user_data - user defined data

Implementors