A trait for an objective function to be minimized
An objective function takes the form of a closure f(x: &[f64], user_data: &mut U) -> f64
x- n-dimensional arrayuser_data- user defined data
A trait for an objective function to be minimized
An objective function takes the form of a closure f(x: &[f64], user_data: &mut U) -> f64
x - n-dimensional arrayuser_data - user defined data